@@ -1,21 +1,14 @@
 #!/bin/sh
 set -e
-# Automatically added by dh_installsystemd/13.3.4
-if [ -d /run/systemd/system ] && [ "$1" = remove ]; then
+# Automatically added by dh_installsystemd/13.11.4
+if [ "$1" = remove ] && [ -d /run/systemd/system ] ; then
 	systemctl --system daemon-reload >/dev/null || true
 fi
 # End automatically added section
-# Automatically added by dh_installsystemd/13.3.4
-if [ "$1" = "remove" ]; then
-	if [ -x "/usr/bin/deb-systemd-helper" ]; then
-		deb-systemd-helper mask 'benno-import-rest.service' >/dev/null || true
-	fi
-fi
-
+# Automatically added by dh_installsystemd/13.11.4
 if [ "$1" = "purge" ]; then
 	if [ -x "/usr/bin/deb-systemd-helper" ]; then
 		deb-systemd-helper purge 'benno-import-rest.service' >/dev/null || true
-		deb-systemd-helper unmask 'benno-import-rest.service' >/dev/null || true
 	fi
 fi
 # End automatically added section
